@@ -247,8 +247,7 @@ class NPOIE(NPOBaseIE):
 
         if not formats:
             if not self.get_param('allow_unplayable_formats') and drm:
-                self.raise_no_formats('This video is DRM protected.', expected=True)
-            return
+                self.report_drm(video_id)
 
         self._sort_formats(formats)
 
